#ifndef SINGLETON_H
#define SINGLETON_H

// Should be placed in the appropriate .cpp file somewhere
#define InitializeSingleton( type ) \
	template < > type * Singleton < type > :: mSingleton = 0

// To be used as a replacement for InitializeSingleton( )
//  Creates a file-scoped Singleton object, to be retrieved with getSingleton
#define createFileSingleton( type ) \
	InitializeSingleton( type ); \
type the##type

template < class type > class Singleton
{
public:
	Singleton () { mSingleton = ( type * ) this; }

	virtual ~Singleton( ) { }

	// Retrieve the singleton object
	static type & getSingleton( ) { return *mSingleton; }

	// Retrieve a pointer to the singleton object
	static type * getSingletonPtr( ) { return mSingleton; }

protected:
	// Singleton pointer, must be set to 0 prior to creating the object
	static type * mSingleton;
};

#endif
