#include "TabAudioJoy.h"
#include "ui_TabAudioJoy.h"

#include "System.h"
#include "Registry.h"

TabAudioJoy::TabAudioJoy( QWidget * parent ) :
	QGroupBox( parent ),
	ui( new Ui::TabAudioJoy )
{
	ui->setupUi( this );

	/* fill misssing data */

	QStringList qstrlAudio = System::enumerateAudioDevices();
	qstrlAudio.append( NOSOUND );
	ui -> qcbSoundSel->addItems( qstrlAudio );
	/* try to set generic as default */
	int nGenericIndex = ui->qcbSoundSel->findText( System::getGenericDevice(), Qt::MatchExactly );
	if( nGenericIndex != -1 )
		ui->qcbSoundSel->setCurrentIndex( nGenericIndex );

	QStringList qstrlJoy = System::enumerateJoystickDevices();
	qstrlJoy.prepend( NOJOYSTICK );
	ui -> qcbJoystickSel->addItems( qstrlJoy );

	QFont qfSmallerFont;
	qfSmallerFont.setPointSize( 8 );
	ui->qlWarning->setFont( qfSmallerFont );
	ui->qlWarning->setText( QString( "WARNING: Setting OpenAL sound device to something other than \"" ) +
							System::getGenericDevice() +
							QString( "\" may make music stop working." ) );

	connect( ui->qcbSoundSel, SIGNAL( currentIndexChanged( const QString& ) ), this, SLOT( setAudioDev( const QString& ) ) );
	connect( ui->qcbSoundSel, SIGNAL( currentIndexChanged( const QString& ) ), this, SLOT( setAudioWarning() ) );
	connect( ui->qcbJoystickSel, SIGNAL( currentIndexChanged( int ) ), this, SLOT( setJoystickDev( int ) ) );
	connect( ui->qcbForceFeedback, SIGNAL( toggled( bool ) ), this, SLOT( setForceFeedback( bool ) ) );
	connect( ui->qcbHitEffect, SIGNAL( toggled( bool ) ), this, SLOT( setHitEffect( bool ) ) );
}

TabAudioJoy::~TabAudioJoy()
{
	delete ui;
}

void TabAudioJoy::updateContent()
{
	/* audio device */
	QString qstrAudio = REGISTRY.getAudioDev();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	int nAudioIndex = ui->qcbSoundSel->findText( qstrAudio, Qt::MatchExactly );
	if( qstrAudio.isEmpty() || nAudioIndex < 0 )
		setAudioDev( ui->qcbSoundSel->currentText() );
	/* otherwise set the value */
	else
		ui->qcbSoundSel->setCurrentIndex( nAudioIndex );
	setAudioWarning();

	/* joystick device */
	int nJoy = REGISTRY.getJoystickDev();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	int nJoyIndex = ( nJoy == 99999 ? 0 : nJoy + 1 );
	if( nJoy < 0 || nJoyIndex >= ui->qcbJoystickSel->count() )
		setJoystickDev( ui->qcbJoystickSel->currentIndex() );
	/* otherwise set the value */
	else
		ui->qcbJoystickSel->setCurrentIndex( nJoyIndex );

	/* force feedback */
	int nFF = REGISTRY.getForceFeedback();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	if( nFF < 0 || nFF > 1 )
		setForceFeedback( ui->qcbForceFeedback->isChecked() );
	/* otherwise set the value */
	else
		ui->qcbForceFeedback->setChecked( nFF );

	/* hit effect */
	int nHE = REGISTRY.getHitEffect();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	if( nHE < 0 || nHE > 1 )
		setHitEffect( ui->qcbHitEffect->isChecked() );
	/* otherwise set the value */
	else
		ui->qcbHitEffect->setChecked( nHE );
}

void TabAudioJoy::setAudioDev( const QString & qstrAudio )
{
	REGISTRY.setAudioDev( qstrAudio );
	emit setRegistryChanged();
}

void TabAudioJoy::setAudioWarning()
{
	QString qstrGeneric = System::getGenericDevice();

	if( qstrGeneric.isEmpty() )
		ui->qlWarning->setHidden( true );
	else
	{
		QString qstrAudio = ui->qcbSoundSel->currentText();

		if( qstrAudio == qstrGeneric || qstrAudio == NOSOUND )
			ui->qlWarning->setHidden( true );
		else
			ui->qlWarning->setHidden( false );
	}
}

void TabAudioJoy::setJoystickDev( const int & nJoy )
{
	int nNewJoy;
	if( nJoy == 0 )
		nNewJoy = 99999;
	else
		nNewJoy = nJoy - 1;

	REGISTRY.setJoystickDev( nNewJoy );
	emit setRegistryChanged();
}

void TabAudioJoy::setForceFeedback( const bool & bFF )
{
	REGISTRY.setForceFeedback( bFF );
	emit setRegistryChanged();
}

void TabAudioJoy::setHitEffect( const bool & bHE )
{
	REGISTRY.setHitEffect( bHE );
	emit setRegistryChanged();
}

void TabAudioJoy::on_qpbCalibrate_clicked()
{
	int nJoy = REGISTRY.getJoystickDev();

	if( nJoy == 99999 )
	{
		System::warning( "No Joystick is setup.", this );
		return;
	}

	System::runCalibrateDialog( nJoy );
}
