#include "TabFeatures.h"
#include "ui_TabFeatures.h"

#include "Settings.h"

TabFeatures::TabFeatures( QWidget *parent ) :
	QGroupBox( parent ),
	ui( new Ui::TabFeatures )
{
	ui->setupUi( this );

	QFont qfSmallerFont;
	qfSmallerFont.setPointSize( 8 );
	ui -> qteFlags -> setFont( qfSmallerFont );
	ui -> qteFlags -> setFixedHeight( 120 );

	qfSmallerFont.setPointSize(7);
	ui -> qlFlagsHelp -> setFont( qfSmallerFont );
	ui -> qlFlagsHelp -> setText( "Double click flag for online documentation on the feature. (WIP)" );

	/* lets connect things */
	connect( ui -> qcbEasySetup, SIGNAL( activated( int ) ), this, SLOT( selectEasyFlagSet( int ) ) );
	connect( ui -> qleCustomFlags, SIGNAL( textChanged( const QString& ) ), this, SLOT( updateCustomFlags( const QString& ) ) );
	connect( ui -> qcbListType, SIGNAL( currentIndexChanged( int ) ), ui-> qwMyCheckBoxList, SLOT( setCurrentIndex( int ) ) );
}

TabFeatures::~TabFeatures()
{
	delete ui;
}

void TabFeatures::updateContent()
{
	/* flags text list */
	ui -> qteFlags -> setText( SETTINGS.generateCmdLine() );

	/* combo box with easy flags sets */
	ui -> qcbEasySetup -> clear();
	for ( int i = 0; i < SETTINGS.getEasyFlagSets().size(); i++ )
		ui -> qcbEasySetup -> insertItem( i, SETTINGS.getEasyFlagSets().at( i ) );

	/* custom flags text edit */
	ui -> qleCustomFlags -> setText( SETTINGS.getCustomFlags() );

	/* combo box with flag types */
	ui -> qcbListType -> clear();
	for ( int i = 0; i < SETTINGS.getFlagTypes().size(); i++ )
		ui -> qcbListType -> insertItem( i, SETTINGS.getFlagTypes().at( i ) );

	/* flags lists */
	ui -> qwMyCheckBoxList -> updateContent();
}

void TabFeatures::selectEasyFlagSet( int nType )
{
	SETTINGS.setEasyTypeSet( nType );
	ui -> qteFlags -> setText( SETTINGS.generateCmdLine() );

	int nIndex = ui -> qwMyCheckBoxList -> currentIndex();
	ui -> qwMyCheckBoxList -> updateContent();
	ui -> qwMyCheckBoxList -> setCurrentIndex( nIndex );
}

void TabFeatures::updateCustomFlags( const QString & qstrFlags )
{
	SETTINGS.setCustomFlags( qstrFlags );
	ui -> qteFlags -> setText( SETTINGS.generateCmdLine() );
}

void TabFeatures::setFlag( const QString & qstrFlag, bool bState )
{
	SETTINGS.setFlag( qstrFlag, bState );
	ui -> qteFlags -> setText( SETTINGS.generateCmdLine() );
}
