#include "TabNetwork.h"
#include "ui_TabNetwork.h"

#include "Registry.h"

TabNetwork::TabNetwork( QWidget * parent ) :
	QGroupBox( parent ),
	ui( new Ui::TabNetwork )
{
	ui->setupUi( this );

	m_qbgNetwork = new QButtonGroup( this );
	m_qbgNetwork -> addButton( ui->qrbInetNone, 0 );
	m_qbgNetwork -> addButton( ui->qrbInetDialup, 1 );
	m_qbgNetwork -> addButton( ui->qrbInetLan, 2 );

	m_qbgSpeed = new QButtonGroup( this );
	m_qbgSpeed -> addButton( ui->qrbSpeedNone, 0 );
	m_qbgSpeed -> addButton( ui->qrbSpeedSlow, 1 );
	m_qbgSpeed -> addButton( ui->qrbSpeedModem, 2 );
	m_qbgSpeed -> addButton( ui->qrbSpeedSingle, 3 );
	m_qbgSpeed -> addButton( ui->qrbSpeedDual, 4 );
	m_qbgSpeed -> addButton( ui->qrbSpeedT, 5 );

	QIntValidator * qiv = new QIntValidator( 0, 65535, this );
	ui->qleLocalPort->setValidator( qiv );
	//QRegExp rx( "\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}" );
	//QRegExpValidator * qrxv = new QRegExpValidator( rx, this );
	//ui->qleIPAddress->setValidator( qrxv );

	connect( m_qbgNetwork, SIGNAL( buttonClicked( int ) ), this, SLOT( setNetworkConnection( int ) ) );
	connect( m_qbgSpeed, SIGNAL( buttonClicked( int ) ), this, SLOT( setConnectionSpeed( int ) ) );
	connect( ui->qleLocalPort, SIGNAL( textChanged( const QString& ) ), this, SLOT( setLocalPort( const QString& ) ) );
	connect( ui->qleIPAddress, SIGNAL( textChanged( const QString& ) ), this, SLOT( setIPAddress( const QString& ) ) );
}

TabNetwork::~TabNetwork()
{
	delete ui;
}

void TabNetwork::updateContent()
{
	/* network connection */
	int nNet = REGISTRY.getNetworkConnection();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	if( nNet < 0 || nNet > 2 )
		setNetworkConnection( m_qbgNetwork->checkedId() );	// this may be -1, we set no default value
	/* otherwise set the value */
	else
		m_qbgNetwork->button( nNet )->click();

	/* connection speed */
	int nSpeed = REGISTRY.getConnectionSpeed();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	if( nSpeed < 0 || nSpeed > 5 )
		setConnectionSpeed( m_qbgSpeed->checkedId() );	// this may be -1, we set no default value
	/* otherwise set the value */
	else
		m_qbgSpeed->button( nSpeed )->click();

	/* local port */
	int nPort = REGISTRY.getLocalPort();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	if( nPort < 0 || nPort > 65535 )
		setLocalPort( ui->qleLocalPort->text() );	// this may be 0, in that case it will remove reg entry
	/* otherwise set the value */
	else
		ui->qleLocalPort->setText( QString( "%1" ).arg( nPort ) );

	/* ip address */
	QString qstrIP = REGISTRY.getIPAddress();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	QRegExp rx( "\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}" );
	if( qstrIP == "" || !rx.exactMatch( qstrIP ) )
		setIPAddress( ui->qleIPAddress->text() );	// this may be empty, in that case it will remove reg entry
	/* otherwise set the value */
	else
		ui->qleIPAddress->setText( qstrIP );
}

void TabNetwork::setNetworkConnection( const int & nNet )
{
	REGISTRY.setNetworkConnection( nNet );
	emit setRegistryChanged();
}
void TabNetwork::setConnectionSpeed( const int & nSpeed )
{
	REGISTRY.setConnectionSpeed( nSpeed );
	emit setRegistryChanged();
}

void TabNetwork::setLocalPort( const QString & qstrPort )
{
	REGISTRY.setLocalPort( qstrPort.toInt() );
	emit setRegistryChanged();
}

void TabNetwork::setIPAddress( const QString & qstrIP )
{
	REGISTRY.setIPAddress( qstrIP );
	emit setRegistryChanged();
}
