#include "TabRegistry.h"
#include "ui_TabRegistry.h"

#include <QtGui>

#include "Registry.h"
#include "FilePaths.h"


TabRegistry::TabRegistry( QWidget * parent ) :
	QGroupBox( parent ),
	ui( new Ui::TabRegistry )
{
	ui->setupUi( this );

	ui -> qleLocation -> setText( FILEPATHS.getRegistry() );

	QFont qfSmallerFont;
	qfSmallerFont.setPointSize( 8 );
	ui->qtwRegistry->setFont( qfSmallerFont );

	QStringList qstrl;
	qstrl << "Name" << "Data" << "Type";
	ui -> qtwRegistry -> setHorizontalHeaderLabels( qstrl );

	connect( ui -> qcbShowAll, SIGNAL( toggled( bool ) ), this, SLOT( updateContent() ) );
	connect( ui -> qcbShowLauncher, SIGNAL( toggled( bool ) ), this, SLOT( updateContent() ) );
}

TabRegistry::~TabRegistry()
{
	delete ui;
}

void TabRegistry::updateContent()
{
	bool bShowAll = ui->qcbShowAll->isChecked();
	bool bShowLauncher = ui->qcbShowLauncher->isChecked();

	const QRegEntryList & qlReg = bShowLauncher ? REGISTRY.getEntries() : REGISTRY.getEntriesSaved();

	ui -> qtwRegistry -> clearContents();
	ui -> qtwRegistry ->setRowCount( 0 );

	for( int i = 0; i < qlReg.size(); ++i )
	{
		const CRegEntry & re = qlReg.at( i );

		QTableWidgetItem * j;
		QString qstrSection = re.m_qstrKey.section( ':' , 0, 0 );

		if( qstrSection == "Default" )
			j = new QTableWidgetItem( re.m_qstrKey.section( ':' , 1, 1 ) );
		else if( bShowAll )
			j = new QTableWidgetItem( re.m_qstrKey );
		else
			continue;
		ui -> qtwRegistry -> setRowCount( ui -> qtwRegistry -> rowCount() + 1 );
		ui -> qtwRegistry -> setItem( i, 0, j );

		switch( re.m_eretType )
		{
		case eretDWORD:
			j = new QTableWidgetItem( "DWORD" );
			break;
		case eretString:
			j = new QTableWidgetItem( "String" );
			break;
		default:
			j = new QTableWidgetItem( "Unknown" );
		}
		ui -> qtwRegistry -> setItem( i, 1, j );

		j = new QTableWidgetItem( re.m_qstrVal );
		ui -> qtwRegistry -> setItem( i, 2, j );
	}

	ui->qtwRegistry->resizeRowsToContents();
	ui->qtwRegistry->resizeColumnsToContents();

	// ugly hack cause resizeColumnsToContents doesn't properly refreshes view on windows
	ui->qtwRegistry->setColumnWidth( 2, 200 );
	ui->qtwRegistry->hideColumn( 2 );
	ui->qtwRegistry->showColumn( 2 );
}
