#include "TabSpeech.h"
#include "ui_TabSpeech.h"

#include "System.h"
#include "Registry.h"

TabSpeech::TabSpeech( QWidget * parent ) :
	QGroupBox( parent ),
	ui( new Ui::TabSpeech )
{
	ui->setupUi( this );

	QFont qfSmallerFont;
	qfSmallerFont.setPointSize( 8 );
	ui->qlAdditional->setFont( qfSmallerFont );
	ui->qlAdditional->setText( "Additional voices like Microsoft Mike and Mary, can be installed for Windows >= 2000." );

	System::speechInit();

	if( !System::speechReady() )
	{
		ui->qteText->setText( "Speech API 5.1 not installed." );
		setEnabled( false );
		return;
	}

	ui->qteText->setText( "Press play to test this string." );
	ui->qcbVoice->addItems( System::enumerateVoices() );

	connect( ui->qcbVoice, SIGNAL( currentIndexChanged( int ) ), this, SLOT( setVoice( int ) ) );
	connect( ui->qcbVoice, SIGNAL( currentIndexChanged( int ) ), this, SLOT( setSpeechVoice() ) );
	connect( ui->qhsVolume, SIGNAL( valueChanged( int ) ), this, SLOT( setVolume( int ) ) );
	connect( ui->qhsVolume, SIGNAL( valueChanged( int ) ), this, SLOT( setSpeechVolume() ) );
	connect( ui->qcbTechroom, SIGNAL( toggled( bool ) ), this, SLOT( setTechRoom( bool ) ) );
	connect( ui->qcbBriefings, SIGNAL( toggled( bool ) ), this, SLOT( setBriefings( bool ) ) );
	connect( ui->qcbIngame, SIGNAL( toggled( bool ) ), this, SLOT( setIngame( bool ) ) );
}

TabSpeech::~TabSpeech()
{
	delete ui;

	System::speechDeinit();
}

void TabSpeech::updateContent()
{
	if( !System::speechReady() )
		return;

	/* voice */
	int nVoice = REGISTRY.getVoice();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	if( nVoice < 0 || nVoice > ui->qcbVoice->count() )
		setVoice( ui->qcbVoice->currentIndex() );
	/* otherwise set the value */
	else
		ui->qcbVoice->setCurrentIndex( nVoice );
	setSpeechVoice();

	/* volume */
	int nVolume = REGISTRY.getVolume();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	if( nVolume < 0 || nVolume > ui->qhsVolume->maximum() )
		setVolume( ui->qhsVolume->value() );
	/* otherwise set the value */
	else
		ui->qhsVolume->setValue( nVolume );
	setSpeechVolume();

	/* tech room */
	int nTechRoom = REGISTRY.getTechRoom();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	if( nTechRoom < 0 || nTechRoom > 1 )
		setTechRoom( ui->qcbTechroom->isChecked() );
	/* otherwise set the value */
	else
		ui->qcbTechroom->setChecked( nTechRoom );

	/* briefings */
	int nBriefings = REGISTRY.getBriefings();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	if( nBriefings < 0 || nBriefings > 1 )
		setBriefings( ui->qcbBriefings->isChecked() );
	/* otherwise set the value */
	else
		ui->qcbBriefings->setChecked( nBriefings );

	/* ingame */
	int nIngame = REGISTRY.getIngame();

	/* nothing is set, or the value is not valid for us, so let's set ours */
	if( nIngame < 0 || nIngame > 1 )
		setIngame( ui->qcbIngame->isChecked() );
	/* otherwise set the value */
	else
		ui->qcbIngame->setChecked( nIngame );
}

void TabSpeech::setVoice( const int & nVoice )
{
	REGISTRY.setVoice( nVoice );
	emit setRegistryChanged();
}

void TabSpeech::setVolume( const int & nVolume )
{
	REGISTRY.setVolume( nVolume );
	emit setRegistryChanged();
}

void TabSpeech::setTechRoom( bool bTechRoom )
{
	REGISTRY.setTechRoom( bTechRoom );
	emit setRegistryChanged();
}

void TabSpeech::setBriefings( bool bBriefings )
{
	REGISTRY.setBriefings( bBriefings );
	emit setRegistryChanged();
}

void TabSpeech::setIngame( bool bIngame )
{
	REGISTRY.setIngame( bIngame );
	emit setRegistryChanged();
}

void TabSpeech::on_qpbPlay_clicked()
{
	System::speechPlay( ui->qteText->toPlainText() );
}

void TabSpeech::on_qpbAdditional_clicked()
{
	System::warning( "The fs2_open project is not responsible for the content of this site or the functionality of the installer on it.", this );
	System::runBrowser( "http://www.microsoft.com/downloads/details.aspx?FamilyId=5E86EC97-40A7-453F-B0EE-6583171B4530&displaylang=en" );
}

void TabSpeech::setSpeechVoice()
{
	System::speechSetVoice( ui->qcbVoice->currentIndex() );
}

void TabSpeech::setSpeechVolume()
{
	System::speechSetVolume( ui->qhsVolume->value() );
}
